@@ -116,7 +116,7 @@ xfsm_systemd_lock_screen (XfsmSystemd  *systemd,
   XfconfChannel *channel;
   gboolean       ret = TRUE;
 
-  channel = xfsm_open_config ();
+  channel = xfconf_channel_get (SETTINGS_CHANNEL);
   if (xfconf_channel_get_bool (channel, "/shutdown/LockScreen", FALSE))
       ret = xfce_screensaver_lock (systemd->screensaver);
 
